1.0.2
=====
* Initial version.
* Feature: document_classifier method
* Feature: DefaultTokenizer, SimpleTokenizer, HtmlTokenizer Class
* Feature: DefaultDocument, SimpleDocument, HtmlDocument Class
* Feature: DefaultDocumentClass, SimpleDocumentClass, HtmlDocumentClass Class
* Feature: Document, DocumentClass Class
* Feature: Tokenizer, TextFilters, WordFilters Class
* Feature: BafOfWords Class




